@@ -97,6 +97,9 @@ class QiDataController:
 
                 file_path = os.path.join(path, trading_date.strftime('%Y%m'))
                 file_path = os.path.join(file_path, instrument_id.split('.')[0] + ".min")
+                if not os.path.exists(file_path):
+                    print('No such file:' + file_path)
+                    return
                 if instrument_id.lower() != 'index':
                     min_bar_steam = MinBarStream(market, instrument_id, file_path)
                     min_bar_steam.read_trading_day(bar_series, trading_date)
@@ -114,6 +117,10 @@ class QiDataController:
                 while date <= end_month:
                     file_path = os.path.join(path, date.strftime('%Y%m'))
                     file_path = os.path.join(file_path, instrument_id.split('.')[0] + ".min")
+                    if not os.path.exists(file_path):
+                        print('No such file:' + file_path)
+                        date = date + relativedelta(months=+1)
+                        continue
                     min_bar_steam = MinBarStream(market, instrument_id, file_path)
                     min_bar_steam.read_trading_days(bar_series, begin_date, end_date)
                     min_bar_steam.close()
@@ -147,6 +154,10 @@ class QiDataController:
                 while date <= end_month:
                     file_path = os.path.join(path, date.strftime('%Y%m'))
                     file_path = os.path.join(file_path, instrument_id.split('.')[0] + ".day")
+                    if not os.path.exists(file_path):
+                        print('No such file:' + file_path)
+                        date = date + relativedelta(months=+1)
+                        continue
                     day_bar_steam = DayBarStream(market, instrument_id, file_path)
                     day_bar_steam.read(bar_series, pre_begin_date, trading_date)
                     date = date + relativedelta(months=+1)
@@ -165,6 +176,10 @@ class QiDataController:
                 while date <= end_month:
                     file_path = os.path.join(path, date.strftime('%Y%m'))
                     file_path = os.path.join(file_path, instrument_id.split('.')[0] + ".day")
+                    if not os.path.exists(file_path):
+                        print('No such file:' + file_path)
+                        date = date + relativedelta(months=+1)
+                        continue
                     day_bar_steam = DayBarStream(market, instrument_id, file_path)
                     day_bar_steam.read(bar_series, pre_begin_date, end_date)
                     date = date + relativedelta(months=+1)
