@@ -30,25 +30,16 @@ qi_data_directory.future_tick_cache = tick_path
 qi_data_directory.future_min = min_path
 qi_data_directory.future_day = day_path
 
-instrument_id = 'j9999'
-begin_trading_date = datetime.datetime(2016, 1, 4)
-end_trading_date = datetime.datetime(2016, 1, 4)
-interval = 120
+instrument_id = 'eg9999'
+begin_trading_date = datetime.datetime(2016, 1, 1)
+end_trading_date = datetime.datetime(2018, 12, 20)
+interval = 1
 bar_type = EnumBarType.minute
 qi_data_controller = QiDataController(qi_data_directory)
-bar_series = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, interval, bar_type, begin_trading_date, end_trading_date)
-print('kline')
+bar_series = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, 1, bar_type, begin_trading_date, end_trading_date)
 for bar in bar_series:
     print(bar.to_string())
 
-time_frame = BaseBarHelper.create_data_frame_in_day_date_time_slice_by_date_consider_holiday(
-    qi_data_controller.instrument_manager, instrument_id, begin_trading_date, end_trading_date, interval, bar_type
-)
-print('time_frame')
-print(time_frame)
-
-
-
 # begin_date = datetime.datetime(2020, 1, 10)
 # end_date = datetime.datetime(2021, 1, 30)
 # t0 = time.time()
